[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples

变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
  保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
  async_reduce, custom_temporary_allocation, explicit_cuda_stream,
  global_device_vector, range_view, unwrap_pointer, wrap_pointer, device

结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
  27/27 tuning headers, 78 benchmarks, 243 tests,
  60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
muh-bot
2026-08-03 12:39:26 +00:00
parent a2a5dd8f00
commit 24ef6a91b5
5439 changed files with 0 additions and 719516 deletions

View File

@@ -1,103 +0,0 @@
//===----------------------------------------------------------------------===//
//
// Part of CUDA Experimental in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2026 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
#ifndef COMMON_GROUP_CUH
#define COMMON_GROUP_CUH
#include <cuda/barrier>
#include <cuda/std/cstddef>
#include <cuda/std/type_traits>
#include <cuda/warp>
#include <cuda/experimental/group.cuh>
#include "testing.cuh"
namespace
{
template <class T, cuda::std::size_t Id>
__device__ T global_barriers_storage;
//! @brief Returns reference to an array of N cuda::barrier objects with suitable thread scope for level allocated in
//! suitable address space (shared or device memory). Id parameter can be used to create unique object.
template <cuda::std::size_t N, cuda::std::size_t Id = 0, class Level>
__device__ auto& get_barriers(const Level& level) noexcept
{
constexpr auto scope = cudax::__minimum_required_scope_for<Level>();
using Barrier = cuda::barrier<scope>;
using BarriersStorage = cuda::std::aligned_storage_t<N * sizeof(Barrier), alignof(Barrier)>;
if constexpr (scope >= cuda::thread_scope_block)
{
__shared__ BarriersStorage shared_barriers_storage;
return reinterpret_cast<Barrier(&)[N]>(shared_barriers_storage);
}
else
{
return reinterpret_cast<Barrier(&)[N]>(global_barriers_storage<BarriersStorage, Id>);
}
}
struct ThreadsInWarpMappingResult
{
__device__ static constexpr ::cuda::std::size_t static_group_count()
{
return 1;
}
__device__ unsigned group_count() const
{
return 1;
}
__device__ unsigned group_rank() const
{
return 0;
}
__device__ static constexpr ::cuda::std::size_t static_unit_count()
{
return 32;
}
__device__ unsigned unit_count() const
{
return 32;
}
__device__ unsigned unit_rank() const
{
return cuda::gpu_thread.rank_as<unsigned>(cuda::warp);
}
__device__ cuda::device::lane_mask lane_mask() const noexcept
{
return cuda::device::lane_mask::all();
}
__device__ bool is_valid() const
{
return true;
}
__device__ static constexpr bool is_always_exhaustive() noexcept
{
return true;
}
__device__ static constexpr bool is_always_contiguous() noexcept
{
return true;
}
};
} // namespace
#endif // COMMON_GROUP_CUH

View File

@@ -1,101 +0,0 @@
//===----------------------------------------------------------------------===//
//
// Part of CUDA Experimental in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
#ifndef __COMMON_HOST_DEVICE_H__
#define __COMMON_HOST_DEVICE_H__
#include "utility.cuh"
template <typename Dims, typename Lambda>
void __global__ lambda_launcher(const Dims dims, const Lambda lambda)
{
lambda(dims);
}
template <typename Comparator, unsigned int FilterArch>
bool arch_filter(const cudaDeviceProp& props)
{
int act_arch = props.major * 10 + props.minor;
if (Comparator()(act_arch, FilterArch))
{
return true;
}
return false;
}
static bool skip_host_exec(bool (* /* filter */)(const cudaDeviceProp&))
{
return false;
}
static bool skip_device_exec(bool (*filter)(const cudaDeviceProp&))
{
cudaDeviceProp props;
REQUIRE_CUDART(cudaGetDeviceProperties(&props, 0));
return filter(props);
}
template <typename Dims, typename Lambda, typename... Filters>
void test_host_dev(const Dims& dims, const Lambda& lambda, const Filters&... filters)
{
SECTION("Host execution")
{
if ((... && !skip_host_exec(filters)))
{
// host testing
lambda(dims);
}
}
SECTION("Device execution")
{
// Asymmetrical but cleaner
if ((... || skip_device_exec(filters)))
{
return;
}
cudaLaunchConfig_t config = {};
config.gridDim = {0};
cudaLaunchAttribute attrs[1];
config.attrs = &attrs[0];
config.blockDim = dims.extents(cuda::gpu_thread, cuda::block);
config.gridDim = dims.extents(cuda::block, cuda::grid);
if constexpr (Dims::has_level(cluster))
{
dim3 cluster_dims = dims.extents(cuda::block, cuda::cluster);
config.attrs[config.numAttrs].id = cudaLaunchAttributeClusterDimension;
config.attrs[config.numAttrs].val.clusterDim = {cluster_dims.x, cluster_dims.y, cluster_dims.z};
config.numAttrs = 1;
}
else
{
config.numAttrs = 0;
}
// device testing
REQUIRE_CUDART(cudaLaunchKernelEx(&config, lambda_launcher<Dims, Lambda>, dims, lambda));
REQUIRE_CUDART(cudaDeviceSynchronize());
}
}
template <typename Fn, typename Tuple>
void apply_each(const Fn& fn, const Tuple& tuple)
{
cuda::std::apply(
[&](const auto&... elems) {
(fn(elems), ...);
},
tuple);
}
#endif // __COMMON_HOST_DEVICE_H__

View File

@@ -1,110 +0,0 @@
//===----------------------------------------------------------------------===//
//
// Part of CUDA Experimental in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
#ifndef __COMMON_TESTING_H__
#define __COMMON_TESTING_H__
#include <cuda/__cccl_config>
#include <cuda/__driver/driver_api.h>
#include <cuda/std/__exception/terminate.h>
#include <nv/target>
#include <exception> // IWYU pragma: keep
#include <iostream>
#include <sstream>
#include <c2h/catch2_test_helper.h>
namespace cuda::experimental::execution
{
}
namespace cudax = cuda::experimental; // NOLINT: misc-unused-alias-decls
namespace cudax_async = cuda::experimental::execution; // NOLINT: misc-unused-alias-decls
__host__ __device__ constexpr bool operator==(const dim3& lhs, const dim3& rhs) noexcept
{
return (lhs.x == rhs.x) && (lhs.y == rhs.y) && (lhs.z == rhs.z);
}
namespace Catch
{
template <>
struct StringMaker<dim3>
{
static std::string convert(dim3 const& dims)
{
std::ostringstream oss;
oss << "(" << dims.x << ", " << dims.y << ", " << dims.z << ")";
return oss.str();
}
};
} // namespace Catch
namespace
{
namespace test
{
inline int count_driver_stack()
{
if (cuda::__driver::__ctxGetCurrent() != nullptr)
{
auto ctx = cuda::__driver::__ctxPop();
auto result = 1 + count_driver_stack();
cuda::__driver::__ctxPush(ctx);
return result;
}
else
{
return 0;
}
}
inline void empty_driver_stack()
{
while (cuda::__driver::__ctxGetCurrent() != nullptr)
{
cuda::__driver::__ctxPop();
}
}
inline int cuda_driver_version()
{
return cuda::__driver::__getVersion();
}
// Needs to be a template because we use template catch2 macro
template <typename Dummy = void>
struct ccclrt_test_fixture
{
ccclrt_test_fixture()
{
empty_driver_stack();
}
~ccclrt_test_fixture()
{
CHECK(count_driver_stack() == 0);
}
};
} // namespace test
} // namespace
// Test macro that should be used in all cccl-rt tests
// It first empties the driver stack in case some other test has left it non-empty
// and then runs the test. At the end it checks if it remained empty, which ensures
// we don't accidentally initialize device 0 through REQUIRE_CUDART usage and makes sure
// our APIs work with empty driver stack.
#define C2H_CCCLRT_TEST(NAME, TAGS, ...) C2H_TEST_WITH_FIXTURE(::test::ccclrt_test_fixture, NAME, TAGS, __VA_ARGS__)
#define C2H_CCCLRT_TEST_LIST(NAME, TAGS, ...) \
C2H_TEST_LIST_WITH_FIXTURE(::test::ccclrt_test_fixture, NAME, TAGS, __VA_ARGS__)
#endif // __COMMON_TESTING_H__

View File

@@ -1,151 +0,0 @@
//===----------------------------------------------------------------------===//
//
// Part of CUDA Experimental in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2024 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
#ifndef __COMMON_UTILITY_H__
#define __COMMON_UTILITY_H__
#include <cuda_runtime_api.h>
// cuda_runtime_api needs to come first
#include <cuda/__runtime/api_wrapper.h>
#include <cuda/__stream/stream_ref.h>
#include <cuda/atomic>
#include <cuda/std/utility>
#include <cuda/experimental/launch.cuh>
#include <new> // IWYU pragma: keep (needed for placement new)
#include "testing.cuh"
namespace
{
namespace test
{
constexpr auto one_thread_dims = cuda::make_config(cuda::block_dims<1>(), cuda::grid_dims<1>());
struct _malloc_pinned
{
private:
void* pv = nullptr;
public:
explicit _malloc_pinned(std::size_t size)
{
cuda::__ensure_current_context guard(cuda::device_ref{0});
_CCCL_TRY_CUDA_API(::cudaMallocHost, "failed to allocate pinned memory", &pv, size);
}
~_malloc_pinned()
{
cuda::__ensure_current_context guard(cuda::device_ref{0});
[[maybe_unused]] auto status = ::cudaFreeHost(pv);
}
template <class T>
T* get_as() const noexcept
{
return static_cast<T*>(pv);
}
};
template <class T>
struct pinned
{
private:
_malloc_pinned _mem;
public:
explicit pinned(T t)
: _mem(sizeof(T))
{
::new (_mem.get_as<void>()) T(std::move(t));
}
~pinned()
{
get()->~T();
}
T* get() noexcept
{
return _mem.get_as<T>();
}
const T* get() const noexcept
{
return _mem.get_as<T>();
}
T& operator*() noexcept
{
return *get();
}
const T& operator*() const noexcept
{
return *get();
}
};
template <int N>
struct assign_n
{
__device__ constexpr void operator()(int* pi) const noexcept
{
*pi = N;
}
};
template <int N>
struct verify_n
{
__device__ void operator()(int* pi) const noexcept
{
REQUIRE_DEVICE(*pi == N);
}
};
using assign_42 = assign_n<42>;
using verify_42 = verify_n<42>;
struct atomic_add_one
{
__device__ void operator()(int* pi) const noexcept
{
cuda::atomic_ref atomic_pi(*pi);
atomic_pi.fetch_add(1);
}
};
struct atomic_sub_one
{
__device__ void operator()(int* pi) const noexcept
{
cuda::atomic_ref atomic_pi(*pi);
atomic_pi.fetch_sub(1);
}
};
struct spin_until_80
{
__device__ void operator()(int* pi) const noexcept
{
cuda::atomic_ref atomic_pi(*pi);
while (atomic_pi.load() != 80)
;
}
};
struct empty_kernel
{
__device__ void operator()() const noexcept {}
};
} // namespace test
} // namespace
#endif // __COMMON_UTILITY_H__